==> anonnet-0.0.1-20011112.tgz: anonnet/src/main.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#ifndef _MAIN_H
#define _MAIN_H 1


/* Defines */
#define USAGE "\
Usage: " ## PACKAGE ## " [OPTIONS...]\n\
\n\
  -c, --config=PATH  path to configuration file\n\
  -p, --port=PORT    bind to specified port (1-65535)\n\
  -r, --random=DEV   path to prng (/dev/urandom, etc)\n\
  -d, --daemon       run as a daemon\n\
  -f, --foreground   run in foreground\n\
  -u, --user=USER    run as user\n\
  -g, --group=GROUP  run as group\n\
  -t, --tty=DEV      force messages to device (defaults console)\n\
  -v, --verbose      output level (range (-v,-vvvv); --verbose = -vvvv)\n\
      --debug        try some dry-run routines\n\
      --help         display this help and exit\n\
      --license      display license information and exit\n\
      --version      display version information and exit\n\
\n\
Report bugs to <wahern@25thandClement.com>."

#define LICENSE "\
Copyright (C) 2001  William Ahern\n\
\n\
This program is free software; you can redistribute it and/or\n\
modify it under the terms of the GNU General Public License\n\
as published by the Free Software Foundation; either version 2\n\
of the License, or (at your option) any later version.\n\
\n\
This program is distributed in the hope that it will be useful,\n\
but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
GNU General Public License for more details.\n\
\n\
You should have received a copy of the GNU General Public License\n\
along with this program; if not, write to the Free Software\n\
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA"


/* Func Declarations */
bool change_privileges(void);

void usage(void);
void license(void);
void version(void);
void debug(void);

#endif /* _MAIN_H */

==> anonnet-0.0.1-20021020.tgz: anonnet/src/main.h <==
/* ==========================================================================
 * AnonNet - Anonymous Network Project
 * --------------------------------------------------------------------------
 * Copyright (C) 2001  William Ahern
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 * ==========================================================================
 */

#ifndef _MAIN_H
#define _MAIN_H 1


/* Defines */
#define USAGE "\
Usage: " ## PACKAGE ## " [OPTIONS...]\n\
\n\
  -c, --config=PATH  path to configuration file\n\
  -p, --port=PORT    bind to specified port (1-65535)\n\
  -l, --listen=ADDR  dotted-quad address to bind\n\
  -r, --random=DEV   path to prng (/dev/urandom, etc)\n\
  -d, --daemon       run as a daemon\n\
  -f, --foreground   run in foreground\n\
  -u, --user=USER    run as user\n\
  -g, --group=GROUP  run as group\n\
  -t, --tty=DEV      force messages to device (defaults console)\n\
  -v, --verbose      output level (-v, -vv, ..., --verbose)\n\
      --debug        try some dry-run routines\n\
      --track-source include source file and line in log messages\n\
      --track-func   include calling function in log messages\n\
      --track-thread include the calling thread in log messages\n\
      --track-all    --track-source, --track-func and --track-thread\n\
      --help         display this help and exit\n\
      --license      display license information and exit\n\
      --version      display version information and exit\n\
\n\
Report bugs to <wahern@25thandClement.com>."

#define LICENSE "\
Copyright (C) 2001  William Ahern\n\
\n\
This program is free software; you can redistribute it and/or\n\
modify it under the terms of the GNU General Public License\n\
as published by the Free Software Foundation; either version 2\n\
of the License, or (at your option) any later version.\n\
\n\
This program is distributed in the hope that it will be useful,\n\
but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
GNU General Public License for more details.\n\
\n\
You should have received a copy of the GNU General Public License\n\
along with this program; if not, write to the Free Software\n\
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA"


/* Func Declarations */
void catch_segv(int);
void signal_handler(void);
void exit_handler(void);
bool change_privileges(void);

void usage(void);
void license(void);
void version(void);
void debug(void);

#endif /* _MAIN_H */
